==> bigdata-common-0.0.120-zgx-20210113.072239-1-sources.jar: cn/com/duiba/bigdata/common/biz/constant/BigdataRedisMetricsKeys.java <==
package cn.com.duiba.bigdata.common.biz.constant;

public class BigdataRedisMetricsKeys {

    //活动请求
    public static final String ACTIVITY_REQUEST = "a_r";

    //活动请求uv
    public static final String ACTIVITY_REQUEST_UV = "a_r_uv";

    //活动参与
    public static final String ACTIVITY_JOIN = "a_j";

    //落地页曝光
    public static final String LANDPAGE_EXPOSURE = "l_e";

    //落地页转化
    public static final String LANDPAGE_CLICK = "l_c";

    //目标转化收益
    public static final String LANDPAGE_CLICK_AFEE = "l_c_af";

    //广告后端转化（总量）
    public static final String BACKEND_CLICK = "b_c";

    //后端转化,含义于 BACKEND_CLICK 相同，重复定义了
    public static final String BACKEND_EFFECT = "b_e";

    //目标转化收益
    public static final String BACKEND_EFFECT_AFEE = "b_e_af";

    //发券量
    public static final String LAUNCH = "l";

    //广告券计费点击
    public static final String EFFECT_CLICK = "ef_c";

    //计费金额(消耗)
    public static final String FEE = "f";

    //底价消耗
    public static final String MIN_FEE = "m_f";

    //广告普通点击
    public static final String CLICK = "c";

    //广告曝光
    public static final String ADVERT_EXPOSURE = "a_e";

    //SDK广告位曝光
    public static final String SDK_SLOT_EXPOSURE = "s_e";

    //SDK广告位点击
    public static final String SDK_SLOT_CLICK = "s_c";

    //广告位曝光(API和新版SDK)
    public static final String API_SLOT_EXPOSURE = "api_s_e";

    //广告位点击(API和新版SDK)
    public static final String API_SLOT_CLICK = "api_s_c";

    //哪吒发券量
    public static final String NEZHA_LAUNCH = "n_l";

    //预估ctr总和
    public static final String PRE_CTR = "p_ctr";

    //预估cvr总和
    public static final String PRE_CVR = "p_cvr";

    //统计ctr总和
    public static final String STAT_CTR = "s_ctr";

    //统计cvr总和
    public static final String STAT_CVR = "s_cvr";

    //平均融合cvr
    public static final String AVG_CVR = "a_cvr";

    //adx消耗
    public static final String ADX_FEE = "x_f";

    //adx点击
    public static final String ADX_CLICK = "x_c";

    //adx曝光
    public static final String ADX_EXPOSURE = "x_e";

    //adx参与竞价数
    public static final String ADX_BID = "x_b";

    //adx竞价 version3.0,区分开
    public static final String ADX_STAT_BID = "x_s_b";

    //adx竞价请求数
    public static final String ADX_BID_REQUEST = "x_b_r";

    //adx竞价成功数
    public static final String ADX_BID_SUCCESS = "x_b_s";

    //adx预估点击价值
    public static final String ADX_PRE_CLICK_VALUE = "x_p_cv";

    //cpc竞价自动
    public static final String RANK_SCORE = "r_s";

    //竞价次数
    public static final String BID_CNT = "b";

    //发券出价总和
    public static final String LAUNCH_FEE = "l_f";

    //发券转化出价总和
    public static final String LAUNCH_AFEE = "l_af";

    //发券日志预估ctr
    public static final String LAUNCH_PRE_CTR = "lp_ctr";

    //发券日志预估cvr
    public static final String LAUNCH_PRE_CVR = "lp_cvr";

    //维稳因子
    public static final String ADJUST_FACTOR = "fa";

    //SDK广告位曝光
    public static final String SLOT_EXPOSURE = "s_e";

    //SDK广告位点击
    public static final String SLOT_CLICK = "s_c";

    //pro_dcvr sum总和数
    public static final String PRE_DCVR = "p_dcvr";

    //pro_dcvr平方和
    public static final String SQ_PRE_DCVR = "sq_p_dcvr";
}

==> bigdata-common-0.0.147-zgx-20210526.053451-1-sources.jar: cn/com/duiba/bigdata/common/biz/constant/BigdataRedisMetricsKeys.java <==
package cn.com.duiba.bigdata.common.biz.constant;

public class BigdataRedisMetricsKeys {

    //活动请求
    public static final String ACTIVITY_REQUEST = "a_r";

    //活动请求uv
    public static final String ACTIVITY_REQUEST_UV = "a_r_uv";

    //活动参与
    public static final String ACTIVITY_JOIN = "a_j";

    //落地页曝光
    public static final String LANDPAGE_EXPOSURE = "l_e";

    //落地页转化
    public static final String LANDPAGE_CLICK = "l_c";

    //目标转化收益
    public static final String LANDPAGE_CLICK_AFEE = "l_c_af";

    //广告后端转化（总量）
    public static final String BACKEND_CLICK = "b_c";

    //后端转化,含义于 BACKEND_CLICK 相同，重复定义了
    public static final String BACKEND_EFFECT = "b_e";

    //目标转化收益
    public static final String BACKEND_EFFECT_AFEE = "b_e_af";

    //发券量
    public static final String LAUNCH = "l";

    //广告券计费点击
    public static final String EFFECT_CLICK = "ef_c";

    //计费金额(消耗)
    public static final String FEE = "f";

    //底价消耗
    public static final String MIN_FEE = "m_f";

    //广告普通点击
    public static final String CLICK = "c";

    //广告曝光
    public static final String ADVERT_EXPOSURE = "a_e";

    //SDK广告位曝光
    public static final String SDK_SLOT_EXPOSURE = "s_e";

    //SDK广告位点击
    public static final String SDK_SLOT_CLICK = "s_c";

    //广告位曝光(API和新版SDK)
    public static final String API_SLOT_EXPOSURE = "api_s_e";

    //广告位点击(API和新版SDK)
    public static final String API_SLOT_CLICK = "api_s_c";

    //哪吒发券量
    public static final String NEZHA_LAUNCH = "n_l";

    //预估ctr总和
    public static final String PRE_CTR = "p_ctr";

    //预估cvr总和
    public static final String PRE_CVR = "p_cvr";

    //统计ctr总和
    public static final String STAT_CTR = "s_ctr";

    //统计cvr总和
    public static final String STAT_CVR = "s_cvr";

    //平均融合cvr
    public static final String AVG_CVR = "a_cvr";

    //adx消耗
    public static final String ADX_FEE = "x_f";

    //adx点击
    public static final String ADX_CLICK = "x_c";

    //adx曝光
    public static final String ADX_EXPOSURE = "x_e";

    //adx参与竞价数
    public static final String ADX_BID = "x_b";

    //adx竞价 version3.0,区分开
    public static final String ADX_STAT_BID = "x_s_b";

    //adx竞价请求数
    public static final String ADX_BID_REQUEST = "x_b_r";

    //adx竞价成功数
    public static final String ADX_BID_SUCCESS = "x_b_s";

    //adx预估点击价值
    public static final String ADX_PRE_CLICK_VALUE = "x_p_cv";

    //cpc竞价自动
    public static final String RANK_SCORE = "r_s";

    //竞价次数
    public static final String BID_CNT = "b";

    //发券出价总和
    public static final String LAUNCH_FEE = "l_f";

    //发券转化出价总和
    public static final String LAUNCH_AFEE = "l_af";

    //发券日志预估ctr
    public static final String LAUNCH_PRE_CTR = "lp_ctr";

    //发券日志预估cvr
    public static final String LAUNCH_PRE_CVR = "lp_cvr";

    //维稳因子
    public static final String ADJUST_FACTOR = "fa";

    //SDK广告位曝光
    public static final String SLOT_EXPOSURE = "s_e";

    //SDK广告位点击
    public static final String SLOT_CLICK = "s_c";

    //pro_dcvr sum总和数
    public static final String PRE_DCVR = "p_dcvr";

    //pro_dcvr平方和
    public static final String SQ_PRE_DCVR = "sq_p_dcvr";

    //落地页目标转化次数
    public static final String TARGET_LANDPAGE_CLICK = "t_l_c";

    //后端目标转化次数
    public static final String TARGET_BACKEND_CLICK = "t_b_c";
}
